@@ -1,11 +1,11 @@
 # The R Commander and command logger
 
-# last modified 23 October 2008 by J. Fox
+# last modified 7 November 2008 by J. Fox
 #   slight changes 12 Aug 04 by Ph. Grosjean
 #   changes 21 June 2007 by Erich Neuwirth for Excel support (marked EN)
 
 Commander <- function(){
-    RcmdrVersion <- "1.4-4"
+    RcmdrVersion <- "1.4-5"
 ##    DESCRIPTION <- readLines(file.path(.find.package("Rcmdr"), "DESCRIPTION")[1])
 ##    RcmdrVersion <- trim.blanks(sub("^Version:", "",
 ##        grep("^Version:", D, value=TRUE)))
@@ -748,8 +748,16 @@ checkWarnings <- function(messages){
     tkfocus(CommanderWindow())
     }
 
+pause <- function(seconds = 1){
+	if (seconds <= 0) stop("seconds must be positive")
+	start <- proc.time()[3]
+	while (as.numeric(elapsed <- (proc.time()[3] - start)) < seconds) {}
+	elapsed
+}
+	
 Message <- function(message, type=c("note", "error", "warning")){
     if (is.SciViews()) return(svMessage(message, type))    # +PhG
+	tcl("update") 
     .message <- MessagesWindow()
     type <- match.arg(type)
     if (type != "note") tkbell()
